@@ -26,7 +26,8 @@ NO_TZ = django.VERSION < (1, 4)
 def _maybe_close_fd(fh):
     try:
         os.close(fh.fileno())
-    except (AttributeError, OSError):
+    except (AttributeError, OSError, TypeError):
+        # TypeError added for celery#962
         pass
 
 
@@ -46,6 +47,7 @@ class DjangoLoader(BaseLoader):
         # Need to close any open database connection after
         # any embedded celerybeat process forks.
         signals.beat_embedded_init.connect(self.close_database)
+        signals.worker_ready.connect(self.warn_if_debug)
 
     def now(self, utc=False):
         return datetime.utcnow() if utc else now()
@@ -76,7 +78,7 @@ class DjangoLoader(BaseLoader):
                 close()
             except DATABASE_ERRORS, exc:
                 str_exc = str(exc)
-                if "closed" not in str_exc and "not connected" in str_exc:
+                if "closed" not in str_exc and "not connected" not in str_exc:
                     raise
 
     def close_database(self, **kwargs):
@@ -120,14 +122,16 @@ class DjangoLoader(BaseLoader):
         listed in ``INSTALLED_APPS``.
 
         """
-        if settings.DEBUG:
-            warnings.warn("Using settings.DEBUG leads to a memory leak, never "
-                          "use this setting in production environments!")
         self.import_default_modules()
 
         self.close_database()
         self.close_cache()
 
+    def warn_if_debug(self, **kwargs):
+        if settings.DEBUG:
+            warnings.warn("Using settings.DEBUG leads to a memory leak, never "
+                          "use this setting in production environments!")
+
     def import_default_modules(self):
         super(DjangoLoader, self).import_default_modules()
         self.autodiscover()
